@@ -2,7 +2,7 @@ use std::{collections::HashSet, ffi::c_void};
 
 use crate::{
     fixed_sized::Bit,
-    handles::{CData, CDataMut, HasDataType, Statement, StatementImpl},
+    handles::{CData, CDataMut, HasDataType, Statement},
     Cursor, DataType, Error, ParameterCollection, RowSetBuffer,
 };
 
@@ -651,7 +651,7 @@ unsafe impl ParameterCollection for &ColumnarRowSet {
         *self.num_rows
     }
 
-    unsafe fn bind_parameters_to(self, stmt: &mut StatementImpl<'_>) -> Result<(), Error> {
+    unsafe fn bind_parameters_to(self, stmt: &mut impl Statement) -> Result<(), Error> {
         for &(parameter_number, ref buffer) in &self.columns {
             stmt.bind_input_parameter(parameter_number, buffer)
                 .into_result(stmt)?;
